@@ -173,7 +173,7 @@ struct SemanticInfoContextManagerItemPrivate : public Ui_SemanticInfoSideBarItem
 
     void setupGroup()
     {
-        mGroup = new SideBarGroup(i18n("Semantic Information"));
+        mGroup = new SideBarGroup(i18n("Semantic Information"), false);
         q->setWidget(mGroup);
         EventWatcher::install(mGroup, QEvent::Show, q, SLOT(update()));
 
@@ -182,6 +182,8 @@ struct SemanticInfoContextManagerItemPrivate : public Ui_SemanticInfoSideBarItem
         container->layout()->setMargin(0);
         mGroup->addWidget(container);
 
+        formLayout->setContentsMargins(DEFAULT_LAYOUT_MARGIN, 0, 0, 0);
+
         QObject::connect(mRatingWidget, SIGNAL(ratingChanged(int)),
                          q, SLOT(slotRatingChanged(int)));
         QObject::connect(mRatingMapper, SIGNAL(mapped(int)),
